# Changelog

## v0.2.0 (2023-09-18)

### Feat

- Support only single-markdown file, remove other markdown types

### Fix

- add extra blank lines before list items
- spacing between ref and paras
- add extra line between details and variables if variable exists
- support list in details

## v0.1.0 (2023-08-10)
